@@ -5,13 +5,22 @@ from typing import Tuple
 import pwn
 import os
 import sys
-client: pwn.tube = None
+from .tube import tube
+client: tube = None
 is_local: bool = False
 tube_file: str = None
 tube_remote: Tuple = None
 elf: ELF = None
 
 
+def attach(gdbscript: str = None):
+    c = check_client()
+    pwn.gdb.attach(
+        target=c,
+        gdbscript=gdbscript,
+    )
+
+
 def is_64_or_86():
     global elf
     if not elf:
@@ -40,6 +49,7 @@ def set_config(config: GameBoxConfig = None):
     global elf
     elf = config.elf
 
+    pwn.context.clear()
     pwn.context.log_level = config.log_level
     pwn.context.os = config.os
     pwn.context.arch = config.arch
@@ -57,7 +67,7 @@ def check_client():
     if not client:
         start_game()
         if not client:
-            logger.error('client not available')
+            logger.error('client not available,please check your config')
             sys.exit(0)
     return client
 
@@ -71,10 +81,16 @@ def start_game(attach_to_client: bool = True):
     local = is_local
     if local:
         global tube_file
+        if not tube_file:
+            logger.warning('local elf-file havn\'t been set')
+            return None
         os.system(f'chmod 777 {tube_file}')
         r = pwn.process(tube_file)
     else:
         global tube_remote
+        if not tube_remote:
+            logger.warning('remote host havn\'t been set')
+            return None
         r = pwn.remote(tube_remote[0], tube_remote[1])
     if attach_to_client:
         global client
